
#include "infowindow.h"
#include <qfileinfo.h>
#include <qtextedit.h>
#include "helper.h"

InfoWindow::InfoWindow( QWidget* parent, const char* name, WFlags fl)
	: InfoWindowBase(parent, name, fl)
{
	row = 0;
}

InfoWindow::~InfoWindow() {
}

void InfoWindow::languageChange() {
	InfoWindowBase::languageChange();

	setData(data);
}

void InfoWindow::setData(MediaData md) {
	data = md;
	QString s;

	// General
	QFileInfo fi(md.filename);
	if (md.type == TYPE_DVD) {
		s += title( "dvd://" + QString::number(Helper::dvdSplitTitle(md.filename) ) );
	} else {
		s += title( md.displayName() );
	}

	s += openPar( tr("General") );
	if (fi.exists()) {
		s += addItem( tr("Path"), fi.dirPath() );
		s += addItem( tr("Size"), tr("%1 KB (%2 MB)").arg(fi.size()/1024)
                                  .arg(fi.size()/1048576) );
	} else {
		s += addItem( tr("URL"), md.filename );
	}
	s += addItem( tr("Length"), Helper::formatTime((int)md.duration) );
	s += addItem( tr("Demuxer"), md.demuxer );
	s += closePar();

	// Clip info
	QString c;
	if (!md.clip_name.isEmpty()) c+= addItem( tr("Name"), md.clip_name );
	if (!md.clip_artist.isEmpty()) c+= addItem( tr("Artist"), md.clip_artist );
	if (!md.clip_author.isEmpty()) c+= addItem( tr("Author"), md.clip_author );
	if (!md.clip_album.isEmpty()) c+= addItem( tr("Album"), md.clip_album );
	if (!md.clip_genre.isEmpty()) c+= addItem( tr("Genre"), md.clip_genre );
	if (!md.clip_date.isEmpty()) c+= addItem( tr("Date"), md.clip_date );
	if (!md.clip_track.isEmpty()) c+= addItem( tr("Track"), md.clip_track );
	if (!md.clip_copyright.isEmpty()) c+= addItem( tr("Copyright"), md.clip_copyright );
	if (!md.clip_comment.isEmpty()) c+= addItem( tr("Comment"), md.clip_comment );
	if (!md.clip_software.isEmpty()) c+= addItem( tr("Software"), md.clip_software );

	if (!c.isEmpty()) {
		s += openPar( tr("Clip info") );
		s += c;
		s += closePar();
	}

	// Video info
	if (!md.novideo) {
		s += openPar( tr("Video") );
		s += addItem( tr("Resolution"), QString("%1 x %2").arg(md.video_width).arg(md.video_height) );
		s += addItem( tr("Aspect ratio"), QString::number(md.video_aspect) );
		s += addItem( tr("Format"), md.video_format );
		s += addItem( tr("Bitrate"), tr("%1 kbps").arg(md.video_bitrate / 1000) );
		s += addItem( tr("Frames per second"), md.video_fps );
		s += addItem( tr("Selected codec"), md.video_codec );
		s += closePar();
	}

	// Audio info
	s += openPar( tr("Initial Audio Stream") );
	s += addItem( tr("Format"), md.audio_format );
	s += addItem( tr("Bitrate"), tr("%1 kbps").arg(md.audio_bitrate / 1000) );
	s += addItem( tr("Rate"), tr("%1 Hz").arg(md.audio_rate) );
	s += addItem( tr("Channels"), QString::number(md.audio_nch) );
	s += addItem( tr("Selected codec"), md.audio_codec );
	s += closePar();

	// Audio Tracks
	if (md.audios.numItems() > 0) {
		s += openPar( tr("Audio Streams") );
		row++;
		s += openItem();
		s += "<td>" + tr("#", "Number abbreviation") + "</td><td>" + 
              tr("Language") + "</td><td>" + tr("Name") +"</td><td>" +
              tr("ID", "Identification code") + "</td>";
		s += closeItem();
		for (int n = 0; n < md.audios.numItems(); n++) {
			row++;
			s += openItem();
			QString lang = md.audios.itemAt(n).lang();
			if (lang.isEmpty()) lang = "<i>&lt;"+tr("empty")+"&gt;</i>";
			QString name = md.audios.itemAt(n).name();
			if (name.isEmpty()) name = "<i>&lt;"+tr("empty")+"&gt;</i>";
			s += QString("<td>%1</td><td>%2</td><td>%3</td><td>%4</td>")
                 .arg(n).arg(lang).arg(name)
                 .arg(md.audios.itemAt(n).ID());
			s += closeItem();
		}
		s += closePar();
	}

	// Subtitles
	if (md.subtitles.numItems() > 0) {
		s += openPar( tr("Subtitles") );
		row++;
		s += openItem();
		s += "<td>" + tr("#", "Number abbreviation") + "</td><td>" + 
              tr("Language") + "</td><td>" + tr("Name") +"</td><td>" +
              tr("ID", "Identification code") + "</td>";
		s += closeItem();
		for (int n = 0; n < md.subtitles.numItems(); n++) {
			row++;
			s += openItem();
			QString lang = md.subtitles.itemAt(n).lang();
			if (lang.isEmpty()) lang = "<i>&lt;"+tr("empty")+"&gt;</i>";
			QString name = md.subtitles.itemAt(n).name();
			if (name.isEmpty()) name = "<i>&lt;"+tr("empty")+"&gt;</i>";
			s += QString("<td>%1</td><td>%2</td><td>%3</td><td>%4</td>")
                 .arg(n).arg(lang).arg(name)
                 .arg(md.subtitles.itemAt(n).ID());
			s += closeItem();
		}
		s += closePar();
	}

	view->setText(s);
}

QString InfoWindow::title(QString text) {
	return "<h1>" + text + "</h1>";
}

QString InfoWindow::openPar(QString text) {
	return "<h2>" + text + "</h2>"
           "<table width=\"100%\">";
}

QString InfoWindow::closePar() {
	row = 0;
	return "</table>";
}

QString InfoWindow::openItem() {
	if (row % 2 == 1)
		return "<tr bgcolor=\"#c4daf4\">";
	else
		return "<tr bgcolor=\"#ffffc6\">";
}

QString InfoWindow::closeItem() {
	return "</tr>";
}

QString InfoWindow::addItem( QString tag, QString value ) {
	row++;
	return openItem() + 
           "<td><b>" + tag + "</b></td>" +
           "<td>" + value + "</td>" +
           closeItem();
}

